Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(166)

Unified Diff: sdk/lib/html/dartium/html_dartium.dart

Issue 23189014: Removing more dom_ methods. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
Download patch
Index: sdk/lib/html/dartium/html_dartium.dart
diff --git a/sdk/lib/html/dartium/html_dartium.dart b/sdk/lib/html/dartium/html_dartium.dart
index a3c3a7c6ced5c9542b5ad3cb1d755d716f72ac16..b16b45b08eeb894b6d276c457bb4b39923363714 100644
--- a/sdk/lib/html/dartium/html_dartium.dart
+++ b/sdk/lib/html/dartium/html_dartium.dart
@@ -7693,7 +7693,7 @@ class Document extends Node
@DomName('Document.createRange')
@DocsEditable()
- Range $dom_createRange() native "Document_createRange_Callback";
+ Range _createRange() native "Document_createRange_Callback";
@DomName('Document.createTextNode')
@DocsEditable()
@@ -10383,11 +10383,11 @@ abstract class Element extends Node implements ParentNode, ChildNode {
@DomName('Element.getAttribute')
@DocsEditable()
- String $dom_getAttribute(String name) native "Element_getAttribute_Callback";
+ String _getAttribute(String name) native "Element_getAttribute_Callback";
@DomName('Element.getAttributeNS')
@DocsEditable()
- String $dom_getAttributeNS(String namespaceURI, String localName) native "Element_getAttributeNS_Callback";
+ String _getAttributeNS(String namespaceURI, String localName) native "Element_getAttributeNS_Callback";
@DomName('Element.getBoundingClientRect')
@DocsEditable()
@@ -10487,11 +10487,11 @@ abstract class Element extends Node implements ParentNode, ChildNode {
@DomName('Element.setAttribute')
@DocsEditable()
- void $dom_setAttribute(String name, String value) native "Element_setAttribute_Callback";
+ void _setAttribute(String name, String value) native "Element_setAttribute_Callback";
@DomName('Element.setAttributeNS')
@DocsEditable()
- void $dom_setAttributeNS(String namespaceURI, String qualifiedName, String value) native "Element_setAttributeNS_Callback";
+ void _setAttributeNS(String namespaceURI, String qualifiedName, String value) native "Element_setAttributeNS_Callback";
@DomName('Element.webkitGetRegionFlowRanges')
@DocsEditable()
@@ -18849,7 +18849,7 @@ class _ChildNodeListLazy extends ListBase<Node> {
_this._replaceChild(value, this[index]);
}
- Iterator<Node> get iterator => _this.$dom_childNodes.iterator;
+ Iterator<Node> get iterator => _this._childNodes.iterator;
// From List<Node>:
@@ -18871,15 +18871,15 @@ class _ChildNodeListLazy extends ListBase<Node> {
// -- end List<Node> mixins.
// TODO(jacobr): benchmark whether this is more efficient or whether caching
- // a local copy of $dom_childNodes is more efficient.
- int get length => _this.$dom_childNodes.length;
+ // a local copy of _childNodes is more efficient.
+ int get length => _this._childNodes.length;
void set length(int value) {
throw new UnsupportedError(
"Cannot set length on immutable List.");
}
- Node operator[](int index) => _this.$dom_childNodes[index];
+ Node operator[](int index) => _this._childNodes[index];
}
/** Information about the instantiated template. */
@@ -19075,7 +19075,7 @@ class Node extends EventTarget {
@DomName('Node.childNodes')
@DocsEditable()
- List<Node> get $dom_childNodes native "Node_childNodes_Getter";
+ List<Node> get _childNodes native "Node_childNodes_Getter";
@DomName('Node.firstChild')
@DocsEditable()
@@ -21006,7 +21006,7 @@ typedef void RtcStatsCallback(RtcStatsResponse response);
@DomName('Range')
@Unstable()
class Range extends NativeFieldWrapperClass1 {
- factory Range() => document.$dom_createRange();
+ factory Range() => document._createRange();
factory Range.fromPoint(Point point) =>
document._caretRangeFromPoint(point.x, point.y);
@@ -29436,15 +29436,15 @@ class _ElementAttributeMap extends _AttributeMap {
}
String operator [](String key) {
- return _element.$dom_getAttribute(key);
+ return _element._getAttribute(key);
}
void operator []=(String key, String value) {
- _element.$dom_setAttribute(key, value);
+ _element._setAttribute(key, value);
}
String remove(String key) {
- String value = _element.$dom_getAttribute(key);
+ String value = _element._getAttribute(key);
_element._removeAttribute(key);
return value;
}
@@ -29473,11 +29473,11 @@ class _NamespacedAttributeMap extends _AttributeMap {
}
String operator [](String key) {
- return _element.$dom_getAttributeNS(_namespace, key);
+ return _element._getAttributeNS(_namespace, key);
}
void operator []=(String key, String value) {
- _element.$dom_setAttributeNS(_namespace, key, value);
+ _element._setAttributeNS(_namespace, key, value);
}
String remove(String key) {

Powered by Google App Engine
This is Rietveld 408576698